@@ -12,9 +12,7 @@ class Permissions(Base):
     @staticmethod
     def validate_permission_id(permission_id):
         if not permission_id or not bool(re.match(r"^[a-z]+\.[a-z]+$", permission_id)):
-            raise IdentifierError(
-                "Invalid permission ID: '{id}'. Does not match ^[a-z]+.[a-z]+$".format(id=permission_id)
-            )
+            raise IdentifierError(f"Invalid permission ID: '{permission_id}'. Does not match ^[a-z]+.[a-z]+$")
 
     def get(self, permission_id, **params):
         self.validate_permission_id(permission_id)
