@@ -5,7 +5,7 @@ class ProfilePayments(Payments):
     profile_id = None
 
     def get_resource_name(self):
-        return "payments?profileId={id}".format(id=self.profile_id)
+        return f"payments?profileId={self.profile_id}"
 
     def with_parent_id(self, profile_id):
         self.profile_id = profile_id
